# raspi-tools

A Python library for managing Raspberry Pi tools such as GPS for neo6 and other tools.

## Features

- GPS data management (fetch, save, and query GPS data)
- GPIO control for Raspberry Pi board LEDs
- Modular and extendable design

## Installation

```bash
pip install raspi-tools
```

## Usage

```bash
from raspi_tools import GPSManager

gps_manager = GPSManager()
gps_manager.run()

```
